@@ -1,4 +1,4 @@
-/* $Id: gdict-about.c,v 1.15 2003/05/19 12:34:23 cneumair Exp $ */
+/* $Id: gdict-about.c,v 1.17 2003/07/22 16:57:17 gman Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -53,7 +53,7 @@ static GtkWidget *gdict_about_new (void)
     
     g_free (file);    
     
-    about = gnome_about_new (_("GNOME Dictionary"), VERSION,
+    about = gnome_about_new (_("Dictionary"), VERSION,
                             "Copyright \xc2\xa9 1999-2003 Mike Hughes",
                             _("A client for the MIT dictionary server."),
 			     (const char **)authors,
@@ -71,10 +71,16 @@ static GtkWidget *gdict_about_new (void)
 
 void gdict_about (GtkWindow *parent)
 {
-    GtkWidget *about = gdict_about_new();
-    if (parent) {
-      gtk_window_set_transient_for (GTK_WINDOW (about), parent) ;
+    static GtkWidget *about = NULL;
+
+    if (about == NULL) {
+      about = gdict_about_new();
+      g_signal_connect (G_OBJECT (about), "destroy",
+			G_CALLBACK (gtk_widget_destroyed), &about);
+      if (parent) {
+        gtk_window_set_transient_for (GTK_WINDOW (about), parent) ;
+      }
     }
-    gtk_widget_show(about);
+    gtk_window_present (GTK_WINDOW (about));
 }
 
