@@ -1,4 +1,4 @@
-/* $Id: gdict-defbox.c,v 1.20 2002/05/10 14:09:33 paolo Exp $ */
+/* $Id: gdict-defbox.c,v 1.21 2003/05/31 06:03:27 dcransto Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -269,13 +269,9 @@ gdict_defbox_find (GDictDefbox *defbox, const gchar *text, gboolean start) {
     GtkTextIter start_iter, end_iter, iter;
     GtkTextIter match_start, match_end;
     GtkTextMark *mark = NULL;
-    static gchar *lastp = NULL;
-    static gchar *deftext = NULL;
-    gchar *findp;
-    gint i = 0;
 
-    g_return_if_fail (defbox != NULL);
-    g_return_if_fail (IS_GDICT_DEFBOX (defbox));
+    g_return_val_if_fail (defbox != NULL, FALSE);
+    g_return_val_if_fail (IS_GDICT_DEFBOX (defbox), FALSE);
     
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (defbox));
     
@@ -495,7 +491,7 @@ insert_text_with_tags (GtkTextBuffer *buffer, GtkTextIter *iter, gchar *p, gint
 static void 
 defbox_add (GDictDefbox *defbox, gchar *def) {
     GtkTextBuffer *buffer;
-    GtkTextIter iter, prev_iter;
+    GtkTextIter iter;
     gchar *p;
     gint len;
     GdkFont *font;
@@ -643,7 +639,7 @@ def_error_cb (dict_command_t *command, DictStatusCode code,
         string = g_strdup_printf (_("Error invoking query: %s"), message);
         dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                   	 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                  	 "%s", string, NULL); 
+                                  	 "%s", string); 
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 	
