@@ -50,6 +50,7 @@
 #include "gsearchtool.h"
 #include "gsearchtool-support.h"
 #include "gsearchtool-callbacks.h"
+#include "gsearchtool-alert-dialog.h"
 
 #include <string.h>
 #include <unistd.h>
@@ -86,7 +87,7 @@ static FindOptionTemplate templates[] = {
 	{ SEARCH_CONSTRAINT_TEXT, "'!' -name '*%s*'", N_("Na_me does not contain"), FALSE },
 	{ SEARCH_CONSTRAINT_TEXT, "-regex '%s'", N_("Name matches regular e_xpression"), FALSE }, 
 	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
-	{ SEARCH_CONSTRAINT_BOOL, "SHOW_HIDDEN_FILES", N_("Show hidden files and folders"), FALSE },
+	{ SEARCH_CONSTRAINT_BOOL, "SHOW_HIDDEN_FILES", N_("Show hidden and backup files"), FALSE },
 	{ SEARCH_CONSTRAINT_BOOL, "-follow", N_("Follow symbolic links"), FALSE },
 	{ SEARCH_CONSTRAINT_BOOL, "INCLUDE_OTHER_FILESYSTEMS", N_("Include other filesystems"), FALSE },
 	{ SEARCH_CONSTRAINT_END, NULL, NULL, FALSE}
@@ -313,7 +314,8 @@ build_search_command (void)
 	command = g_string_new ("");
 	search_command.show_hidden_files = FALSE;
 	
-	if (GTK_WIDGET_VISIBLE(interface.additional_constraints) == FALSE) {
+	if ((GTK_WIDGET_VISIBLE(interface.additional_constraints) == FALSE) ||
+	    (interface.selected_constraints == NULL)) {
 	
 		gchar *locate;
 		gboolean disable_quick_search;
@@ -414,12 +416,12 @@ build_search_command (void)
 					 		templates[constraint->constraint_id].option,
 					  		constraint->data.time);
 				g_string_append_c (command, ' ');
-				break;
+				break;	
 			case SEARCH_CONSTRAINT_TIME_MORE:
 				g_string_append_printf (command,
 					 		templates[constraint->constraint_id].option,
 					  		constraint->data.time,
-							constraint->data.time);
+					  		constraint->data.time);
 				g_string_append_c (command, ' ');
 				break;
 			default:
@@ -544,6 +546,57 @@ add_no_files_found_message (GtkListStore 	*store,
 		    	    -1);
 }
 
+void
+update_search_counts (void)
+{
+	gchar  *title_bar_string = NULL;
+	gchar  *message_string = NULL;
+	gchar  *stopped_string = g_strdup ("");
+	gchar  *tmp;
+	gint   total_files;
+
+	if (search_command.aborted == TRUE) {
+		stopped_string = g_strdup (_("(stopped)"));
+	}
+	
+	total_files = gtk_tree_model_iter_n_children (GTK_TREE_MODEL(interface.model), NULL);
+
+	if (total_files == 0) {
+		title_bar_string = g_strdup (_("No Files Found"));
+		message_string = g_strdup (_("No files found"));
+		add_no_files_found_message (interface.model, &interface.iter);
+	}
+	else {
+		title_bar_string = ngettext ("%d File Found",
+					     "%d Files Found",
+					     total_files);
+		message_string = ngettext ("%d file found",
+					   "%d files found",
+					   total_files);
+	}
+
+	if (strlen (stopped_string) > 0) {
+		tmp = message_string;
+		message_string = g_strconcat (message_string, " ", stopped_string, NULL);
+		g_free (tmp);
+		
+		tmp = title_bar_string;
+		title_bar_string = g_strconcat (title_bar_string, " ", stopped_string, NULL);
+		g_free (tmp);
+	}
+		
+	tmp = title_bar_string;
+	title_bar_string = g_strconcat (title_bar_string, " - ", _("Search for Files"), NULL);
+	gtk_window_set_title (GTK_WINDOW (interface.main_window), title_bar_string);
+	g_free (tmp);
+	
+	gtk_label_set_text (GTK_LABEL (interface.results_label), message_string);
+	
+	g_free (title_bar_string);
+	g_free (message_string);
+	g_free (stopped_string);
+}
+
 static GtkWidget *
 make_list_of_templates (void)
 {
@@ -557,7 +610,7 @@ make_list_of_templates (void)
 	for(i=0; templates[i].type != SEARCH_CONSTRAINT_END; i++) {
 		
 		if (templates[i].type == SEARCH_CONSTRAINT_SEPARATOR) {
-			menuitem = gtk_separator_menu_item_new ();
+			menuitem = gtk_separator_menu_item_new ();	
 			gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 			gtk_widget_show (menuitem);
 		} 
@@ -1202,7 +1255,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 								add_file_to_search_results (string->str, interface.model, &interface.iter);
 							}
 						}
-						else if (is_path_hidden (string->str) == FALSE) {
+						else if ((is_path_hidden (string->str) == FALSE) && (!file_extension_is (string->str, "~"))) {
 							if (search_data->regex_matching_enabled == FALSE) {
 								add_file_to_search_results (string->str, interface.model, &interface.iter);
 							} 
@@ -1238,65 +1291,28 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 	}
 
 	if (condition != G_IO_IN || broken_pipe == TRUE) { 
-	
-		gint   total_files;
-		gchar *status_bar_string = NULL;
-		gchar *title_bar_string = NULL;
-		gchar *search_status = g_strdup ("");
-		gchar  *tmp;
 		
 		if (search_data->running == MAKE_IT_STOP) {
-			search_status = g_strdup (_("(stopped)"));
+			search_data->aborted = TRUE;
 		}
 		
 		search_data->lock = FALSE;
 		search_data->running = NOT_RUNNING;
-		
 		search_data->not_running_timeout = TRUE;
 		g_timeout_add (500, not_running_timeout_cb, NULL);
 
-		total_files = gtk_tree_model_iter_n_children (GTK_TREE_MODEL(interface.model), NULL);
-
-		if (total_files == 0) {
-			status_bar_string = g_strdup (_("No files found"));
-			title_bar_string = g_strdup (_("No Files Found"));
-			add_no_files_found_message (interface.model, &interface.iter);
-		}
-		else if (total_files == 1) {
-			status_bar_string = g_strdup (_("One file found"));
-			title_bar_string = g_strdup (_("One File Found"));
-		}
-		else {
-			status_bar_string = g_strdup_printf (_("%d files found"), total_files);
-			title_bar_string = g_strdup_printf (_("%d Files Found"), total_files);
-		}
-		
-		if (strlen(search_status) > 0) {
-			status_bar_string = g_strconcat (status_bar_string, " ", search_status, NULL);
-			title_bar_string = g_strconcat (title_bar_string, " ", search_status, NULL);
-		}
-		gtk_label_set_text (GTK_LABEL (interface.results_label), status_bar_string);
-		
-		tmp = title_bar_string;
-		title_bar_string = g_strconcat (title_bar_string, " - ", _("Search for Files"), NULL);
-		gtk_window_set_title (GTK_WINDOW (interface.main_window), title_bar_string);
-		g_free (tmp);
-
+		update_search_counts ();
 		stop_animation ();
 
 		gtk_window_set_default (GTK_WINDOW(interface.main_window), interface.find_button);
 		gtk_widget_set_sensitive (interface.additional_constraints, TRUE);
-		gtk_widget_set_sensitive (interface.checkbutton, TRUE);
+		gtk_widget_set_sensitive (interface.expander, TRUE);
 		gtk_widget_set_sensitive (interface.table, TRUE);
 		gtk_widget_set_sensitive (interface.find_button, TRUE);
 		gtk_widget_hide (interface.stop_button);
 		gtk_widget_show (interface.find_button);
 
 		g_io_channel_shutdown (ioc, TRUE, NULL);
-		g_free (status_bar_string);
-		g_free (title_bar_string);
-		g_free (search_status);
-		
 		return FALSE;
 	}
 	return TRUE;
@@ -1390,11 +1406,13 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 				     		_("\n... Too many errors to display ..."));
 				}
 				
-				dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-				                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-								     GTK_BUTTONS_OK,
-				                                     _("Error while searching for files"),
-				                                     error_msgs->str);
+				dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                	                           GTK_DIALOG_DESTROY_WITH_PARENT,
+						                   GTK_MESSAGE_ERROR,
+							           GTK_BUTTONS_OK,
+							           _("Error while searching for files."),
+							           error_msgs->str,
+							           NULL);
 				
 				g_signal_connect (G_OBJECT (dialog),
 					"response",
@@ -1429,11 +1447,13 @@ spawn_search_command (gchar *command)
 
 		stop_animation ();
 
-		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-		                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-						     GTK_BUTTONS_OK,
-					             _("Error parsing the search command"),
-					             (error != NULL) ? error->message : "");
+		dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+	                                           GTK_DIALOG_DESTROY_WITH_PARENT,
+				                   GTK_MESSAGE_ERROR,
+					           GTK_BUTTONS_OK,
+					           _("Error parsing the search command."),
+					           (error == NULL) ? NULL : error->message,
+					           NULL);
 
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
@@ -1449,13 +1469,15 @@ spawn_search_command (gchar *command)
 		GtkWidget *dialog;
 		
 		stop_animation ();
-						
-		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-		                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-						     GTK_BUTTONS_OK,
-					             _("Error running the search command"),
-					             (error != NULL) ? error->message : "");
-
+		
+		dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+	                                           GTK_DIALOG_DESTROY_WITH_PARENT,
+				                   GTK_MESSAGE_ERROR,
+					           GTK_BUTTONS_OK,
+					           _("Error running the search command."),
+					           (error == NULL) ? NULL : error->message,
+					           NULL);
+							   
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		g_error_free (error);
@@ -1463,6 +1485,7 @@ spawn_search_command (gchar *command)
 	}
 	
 	search_command.lock = TRUE;
+	search_command.aborted = FALSE;
 	search_command.running = RUNNING; 
 
 	gtk_window_set_default (GTK_WINDOW(interface.main_window), interface.stop_button);
@@ -1472,7 +1495,7 @@ spawn_search_command (gchar *command)
 	gtk_widget_set_sensitive (interface.find_button, FALSE);
 	gtk_widget_set_sensitive (interface.results, TRUE);
 	gtk_widget_set_sensitive (interface.additional_constraints, FALSE);
-	gtk_widget_set_sensitive (interface.checkbutton, FALSE);
+	gtk_widget_set_sensitive (interface.expander, FALSE);
 	gtk_widget_set_sensitive (interface.table, FALSE);
 
 	gtk_tree_view_scroll_to_point (GTK_TREE_VIEW(interface.tree), 0, 0);
@@ -1601,7 +1624,7 @@ add_constraint (gint constraint_id, gchar *value, gboolean show_constraint)
 
 	if (show_constraint) {
 		if (GTK_WIDGET_VISIBLE (interface.additional_constraints) == FALSE) {
-			g_signal_emit_by_name (G_OBJECT(interface.checkbutton), "clicked", 0);
+			gtk_expander_set_expanded (GTK_EXPANDER (interface.expander), TRUE);
 			gtk_widget_show (interface.additional_constraints);
 		}
 	} 
@@ -1728,7 +1751,7 @@ create_search_results_section (void)
 	gtk_drag_source_set (interface.tree, 
 			     GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,
 			     dnd_table, n_dnds, 
-			     GDK_ACTION_COPY | GDK_ACTION_MOVE);	
+			     GDK_ACTION_COPY | GDK_ACTION_MOVE | GDK_ACTION_ASK);	
 
 	g_signal_connect (G_OBJECT (interface.tree), 
 			  "drag_data_get",
@@ -1944,14 +1967,21 @@ create_main_window (void)
 	g_free (locale_string);
 	g_free (utf8_string);
 	
-	interface.checkbutton = gtk_check_button_new_with_mnemonic (_("Show more _options"));
-	gtk_box_pack_start (GTK_BOX(window), interface.checkbutton, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (interface.checkbutton),"clicked",
-			  G_CALLBACK (click_check_button_cb), NULL);
-			  
+	interface.expander = gtk_expander_new_with_mnemonic (_("Show more _options"));
+	gtk_box_pack_start (GTK_BOX(window), interface.expander, FALSE, FALSE, 0);
+	g_signal_connect (G_OBJECT (interface.expander),"notify::expanded",
+			  G_CALLBACK (click_expander_cb), NULL);
+	
 	interface.additional_constraints = create_additional_constraint_section ();
 	gtk_box_pack_start (GTK_BOX(window), GTK_WIDGET(interface.additional_constraints), FALSE, FALSE, 0);
 	
+	if (interface.is_gail_loaded)
+	{ 
+		add_atk_namedesc (GTK_WIDGET (interface.expander), _("Show more options"), _("Expands or collapses a list of search options."));
+		add_atk_relation (GTK_WIDGET (interface.additional_constraints), GTK_WIDGET (interface.expander), ATK_RELATION_CONTROLLED_BY);
+		add_atk_relation (GTK_WIDGET (interface.expander), GTK_WIDGET (interface.additional_constraints), ATK_RELATION_CONTROLLER_FOR);
+	}
+	
 	vbox = gtk_vbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (window), vbox, TRUE, TRUE, 0);
 	
@@ -2171,7 +2201,7 @@ handle_gconf_settings (void)
 {
 	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/show_additional_options")) {
 		if (GTK_WIDGET_VISIBLE (interface.additional_constraints) == FALSE) {
-			g_signal_emit_by_name (G_OBJECT(interface.checkbutton), "clicked", 0);
+			gtk_expander_set_expanded (GTK_EXPANDER (interface.expander), TRUE);
 			gtk_widget_show (interface.additional_constraints);
 		}
 	}
